@@ -1,7 +1,7 @@
 /*
  *      datatypes.h
  *
- *      Copyright 2008 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ *      Copyright 2008-2010 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -37,4 +37,28 @@ typedef struct
 	gboolean sorted;
 } CategoryName;
 
+typedef struct
+{
+	gchar *filepath;
+	gchar *label;
+	GString *template;
+} TemplateEntry;
+
+typedef struct
+{
+	GtkWidget *documentclass_combobox;
+	GtkWidget *encoding_combobox;
+	GtkWidget *fontsize_combobox;
+	GtkWidget *checkbox_KOMA;
+	GtkWidget *author_textbox;
+	GtkWidget *date_textbox;
+	GtkWidget *title_textbox;
+	GtkWidget *papersize_combobox;
+	GtkWidget *checkbox_draft;
+	GtkWidget *template_combobox;
+	GtkWidget *orientation_combobox;
+	GPtrArray *template_list;
+	gboolean draft_active;
+} LaTeXWizard;
+
 #endif
