@@ -29,10 +29,6 @@
 #include <glib/gstdio.h>
 #include <unistd.h>
 
-#ifdef HAVE_LOCALE_H
-# include <locale.h>
-#endif
-
 #include "geanyvc.h"
 #include "geanyplugin.h"
 #include "SciLexer.h"
@@ -50,7 +46,7 @@ GeanyData *geany_data;
 GeanyFunctions *geany_functions;
 
 PLUGIN_VERSION_CHECK(115);
-PLUGIN_SET_INFO(_("VC"), _("Interface to different Version Control systems."), VERSION,
+PLUGIN_SET_INFO(_("GeanyVC"), _("Interface to different Version Control systems."), VERSION,
 		_("Yura Siamashka <yurand2@gmail.com>,\nFrank Lanitz <frank@frank.uvena.de>"));
 
 /* Some global variables */
@@ -1512,14 +1508,18 @@ vccommit_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 	set_diff_buff(diffbuf, diff);
 
 	if (set_maximize_commit_dialog)
+	{
 		gtk_window_maximize(GTK_WINDOW(commit));
+	}
 	else
+	{
 		gtk_widget_set_size_request(commit, 700, 500);
+	}
 
-		gtk_widget_show_now(commit);
-		gtk_window_get_size(GTK_WINDOW(commit), NULL, &height);
-		gtk_paned_set_position(GTK_PANED(vpaned1), height * 30 / 100);
-		gtk_paned_set_position(GTK_PANED(vpaned2), height * 55 / 100);
+	gtk_widget_show_now(commit);
+	gtk_window_get_size(GTK_WINDOW(commit), NULL, &height);
+	gtk_paned_set_position(GTK_PANED(vpaned1), height * 30 / 100);
+	gtk_paned_set_position(GTK_PANED(vpaned2), height * 55 / 100);
 
 #ifdef USE_GTKSPELL
 	speller = gtkspell_new_attach(GTK_TEXT_VIEW(messageView), NULL, &spellcheck_error);
@@ -1530,7 +1530,7 @@ vccommit_activated(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer
 		g_error_free(spellcheck_error);
 		spellcheck_error = NULL;
 	}
-	else if (lang != NULL)
+	else if (NZV(lang))
 	{
 		gtkspell_set_language(speller, lang, &spellcheck_error);
 		if (spellcheck_error != NULL)
@@ -2007,7 +2007,7 @@ do_current_file_menu(GtkWidget ** parent_menu, gboolean editor_menu)
 	gtk_container_add(GTK_CONTAINER(cur_file_menu), gtk_separator_menu_item_new());
 
 	/* History/log of current file */
-	menu_vc_log_file = gtk_menu_item_new_with_mnemonic(_("_History"));
+	menu_vc_log_file = gtk_menu_item_new_with_mnemonic(_("_History (log)"));
 	gtk_container_add(GTK_CONTAINER(cur_file_menu), menu_vc_log_file);
 	ui_widget_set_tooltip_text(menu_vc_log_file,
 			     _("Shows the log of the current file"));
@@ -2073,7 +2073,7 @@ do_current_dir_menu(GtkWidget ** parent_menu)
 
 	gtk_container_add(GTK_CONTAINER(cur_dir_menu), gtk_separator_menu_item_new());
 	/* History/log of the current dir */
-	menu_vc_log_dir = gtk_menu_item_new_with_mnemonic(_("_History"));
+	menu_vc_log_dir = gtk_menu_item_new_with_mnemonic(_("_History (log)"));
 	gtk_container_add(GTK_CONTAINER(cur_dir_menu), menu_vc_log_dir);
 	ui_widget_set_tooltip_text(menu_vc_log_dir,
 			     _("Shows the log of the current directory"));
@@ -2114,7 +2114,7 @@ do_basedir_menu(GtkWidget ** parent_menu)
 			 G_CALLBACK(vclog_dir_activated), NULL);
 
 	/* Complete History/Log of base directory */
-	menu_vc_log_basedir = gtk_menu_item_new_with_mnemonic(_("_History"));
+	menu_vc_log_basedir = gtk_menu_item_new_with_mnemonic(_("_History (log)"));
 	gtk_container_add(GTK_CONTAINER(basedir_menu), menu_vc_log_basedir);
 	ui_widget_set_tooltip_text(menu_vc_log_basedir,
 			     _("Shows the log of the top VC directory"));
@@ -2245,7 +2245,7 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	/* complete update */
 	menu_vc_update = gtk_menu_item_new_with_mnemonic(_("_Update"));
 	gtk_container_add(GTK_CONTAINER(menu_vc_menu), menu_vc_update);
-	ui_widget_set_tooltip_text(menu_vc_update, _("Update from remote repositary."));
+	ui_widget_set_tooltip_text(menu_vc_update, _("Update from remote repository."));
 
 	g_signal_connect(menu_vc_update, "activate", G_CALLBACK(vcupdate_activated), NULL);
 
@@ -2257,9 +2257,6 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	g_signal_connect(menu_vc_commit, "activate", G_CALLBACK(vccommit_activated), NULL);
 
 	gtk_widget_show_all(menu_vc);
-	gtk_widget_show_all(menu_vc_file);
-	gtk_widget_show_all(menu_vc_dir);
-	gtk_widget_show_all(menu_vc_basedir);
 
 	/* initialize keybindings */
 	init_keybindings();
