@@ -1,8 +1,8 @@
 /*
  *      gui.c - this file is part of Spellcheck, a Geany plugin
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2008-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2008-2010 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -202,6 +202,42 @@ static GtkWidget *image_menu_item_new(const gchar *stock_id, const gchar *label)
 }
 
 
+static GtkWidget *init_editor_submenu(void)
+{
+	if (sc_info->edit_menu_sub != NULL && GTK_IS_WIDGET(sc_info->edit_menu_sub))
+		gtk_widget_destroy(sc_info->edit_menu_sub);
+
+	sc_info->edit_menu_sub = gtk_menu_new();
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(sc_info->edit_menu), sc_info->edit_menu_sub);
+
+	gtk_widget_show(sc_info->edit_menu);
+	gtk_widget_show(sc_info->edit_menu_sep);
+	gtk_widget_show(sc_info->edit_menu_sub);
+
+	return sc_info->edit_menu_sub;
+}
+
+
+static void perform_check(GeanyDocument *doc)
+{
+	editor_indicator_clear(doc->editor, GEANY_INDICATOR_ERROR);
+
+	if (sc_info->use_msgwin)
+	{
+		msgwin_clear_tab(MSG_MESSAGE);
+		msgwin_switch_tab(MSG_MESSAGE, FALSE);
+	}
+
+	sc_speller_check_document(doc);
+}
+
+
+static void perform_spell_check_cb(GtkWidget *menu_item, GeanyDocument *doc)
+{
+	perform_check(doc);
+}
+
+
 void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 								  GeanyDocument *doc, gpointer user_data)
 {
@@ -213,6 +249,9 @@ void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 	gtk_widget_hide(sc_info->edit_menu);
 	gtk_widget_hide(sc_info->edit_menu_sep);
 
+	if (! sc_info->show_editor_menu_item)
+		return;
+
 	/* if we have a selection, prefer it over the current word */
 	if (sci_has_selection(doc->editor->sci))
 	{
@@ -230,6 +269,27 @@ void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 		return;
 	}
 
+	/* ignore too long search words */
+	if (strlen(search_word) > 100)
+	{
+		GtkWidget *menu_item;
+
+		init_editor_submenu();
+		menu_item = gtk_menu_item_new_with_label(
+			_("Search term is too long to provide\nspelling suggestions in the editor menu."));
+		gtk_widget_set_sensitive(menu_item, FALSE);
+		gtk_widget_show(menu_item);
+		gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
+
+		menu_item = gtk_menu_item_new_with_label(_("Perform Spell Check"));
+		gtk_widget_show(menu_item);
+		gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
+		g_signal_connect(menu_item, "activate", G_CALLBACK(perform_spell_check_cb), doc);
+
+		g_free(search_word);
+		return;
+	}
+
 	if (sc_speller_dict_check(search_word) != 0)
 	{
 		GtkWidget *menu_item, *menu;
@@ -243,11 +303,7 @@ void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 		clickinfo.doc = doc;
 		setptr(clickinfo.word, search_word);
 
-		if (sc_info->edit_menu_sub != NULL && GTK_IS_WIDGET(sc_info->edit_menu_sub))
-			gtk_widget_destroy(sc_info->edit_menu_sub);
-
-		sc_info->edit_menu_sub = menu = gtk_menu_new();
-		gtk_menu_item_set_submenu(GTK_MENU_ITEM(sc_info->edit_menu), sc_info->edit_menu_sub);
+		menu = init_editor_submenu();
 
 		for (i = 0; i < n_suggs; i++)
 		{
@@ -265,6 +321,7 @@ void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 				gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item), menu);
 			}
 			menu_item = gtk_menu_item_new_with_label(suggs[i]);
+			gtk_widget_show(menu_item);
 			gtk_container_add(GTK_CONTAINER(menu), menu_item);
 			g_signal_connect(menu_item, "activate",
 				G_CALLBACK(menu_suggestion_item_activate_cb), NULL);
@@ -273,26 +330,26 @@ void sc_gui_update_editor_menu_cb(GObject *obj, const gchar *word, gint pos,
 		{
 			menu_item = gtk_menu_item_new_with_label(_("(No Suggestions)"));
 			gtk_widget_set_sensitive(menu_item, FALSE);
+			gtk_widget_show(menu_item);
 			gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
 		}
 		menu_item = gtk_separator_menu_item_new();
+		gtk_widget_show(menu_item);
 		gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
 
 		label = g_strdup_printf(_("Add \"%s\" to Dictionary"), search_word);
 		menu_item = image_menu_item_new(GTK_STOCK_ADD, label);
+		gtk_widget_show(menu_item);
 		gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
 		g_signal_connect(menu_item, "activate",
 			G_CALLBACK(menu_addword_item_activate_cb), GINT_TO_POINTER(0));
 
 		menu_item = image_menu_item_new(GTK_STOCK_REMOVE, _("Ignore All"));
+		gtk_widget_show(menu_item);
 		gtk_container_add(GTK_CONTAINER(sc_info->edit_menu_sub), menu_item);
 		g_signal_connect(menu_item, "activate",
 			G_CALLBACK(menu_addword_item_activate_cb), GINT_TO_POINTER(1));
 
-		gtk_widget_show(sc_info->edit_menu);
-		gtk_widget_show(sc_info->edit_menu_sep);
-		gtk_widget_show_all(sc_info->edit_menu_sub);
-
 		if (suggs != NULL)
 			sc_speller_dict_free_string_list(suggs);
 
@@ -447,20 +504,13 @@ static void menu_item_toggled_cb(GtkCheckMenuItem *menuitem, gpointer gdata)
 		update_labels();
 	}
 
-	editor_indicator_clear(doc->editor, GEANY_INDICATOR_ERROR);
-	if (sc_info->use_msgwin)
-	{
-		msgwin_clear_tab(MSG_MESSAGE);
-		msgwin_switch_tab(MSG_MESSAGE, FALSE);
-	}
-
-	sc_speller_check_document(doc);
+	perform_check(doc);
 }
 
 
 void sc_gui_kb_run_activate_cb(guint key_id)
 {
-	menu_item_toggled_cb(NULL, NULL);
+	perform_check(document_get_current());
 }
 
 
