@@ -1,8 +1,8 @@
 /*
  *      scplugin.c - this file is part of Spellcheck, a Geany plugin
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2008-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2008-2010 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -36,9 +36,14 @@ GeanyData		*geany_data;
 GeanyFunctions	*geany_functions;
 
 
-PLUGIN_VERSION_CHECK(147);
-PLUGIN_SET_INFO(_("Spell Check"), _("Checks the spelling of the current document."), VERSION,
-			_("The Geany developer team"))
+PLUGIN_VERSION_CHECK(188)
+PLUGIN_SET_TRANSLATABLE_INFO(
+	LOCALEDIR,
+	GETTEXT_PACKAGE,
+	_("Spell Check"),
+	_("Checks the spelling of the current document."),
+	VERSION,
+	"The Geany developer team")
 
 
 SpellCheck *sc_info = NULL;
@@ -108,13 +113,23 @@ static void configure_response_cb(GtkDialog *dialog, gint response, gpointer use
 		sc_info->show_toolbar_item = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
 			g_object_get_data(G_OBJECT(dialog), "check_toolbar"))));
 
+		sc_info->show_editor_menu_item = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+			g_object_get_data(G_OBJECT(dialog), "check_editor_menu"))));
+
 		g_key_file_load_from_file(config, sc_info->config_file, G_KEY_FILE_NONE, NULL);
 		if (sc_info->default_language != NULL) /* lang may be NULL */
 			g_key_file_set_string(config, "spellcheck", "language", sc_info->default_language);
-		g_key_file_set_boolean(config, "spellcheck", "check_while_typing", sc_info->check_while_typing);
-		g_key_file_set_boolean(config, "spellcheck", "use_msgwin", sc_info->use_msgwin);
-		g_key_file_set_boolean(config, "spellcheck", "show_toolbar_item", sc_info->show_toolbar_item);
-		g_key_file_set_string(config, "spellcheck", "dictionary_dir", sc_info->dictionary_dir);
+		g_key_file_set_boolean(config, "spellcheck", "check_while_typing",
+			sc_info->check_while_typing);
+		g_key_file_set_boolean(config, "spellcheck", "use_msgwin",
+			sc_info->use_msgwin);
+		g_key_file_set_boolean(config, "spellcheck", "show_toolbar_item",
+			sc_info->show_toolbar_item);
+		g_key_file_set_boolean(config, "spellcheck", "show_editor_menu_item",
+			sc_info->show_editor_menu_item);
+	   if (sc_info->dictionary_dir != NULL)
+			g_key_file_set_string(config, "spellcheck", "dictionary_dir",
+				sc_info->dictionary_dir);
 
 		sc_gui_update_toolbar();
 		sc_gui_update_menu();
@@ -146,7 +161,8 @@ void plugin_init(GeanyData *data)
 	default_lang = sc_speller_get_default_lang();
 	sc_info = g_new0(SpellCheck, 1);
 
-	sc_info->config_file = g_strconcat(geany->app->configdir, G_DIR_SEPARATOR_S, "plugins", G_DIR_SEPARATOR_S,
+	sc_info->config_file = g_strconcat(geany->app->configdir,
+		G_DIR_SEPARATOR_S, "plugins", G_DIR_SEPARATOR_S,
 		"spellcheck", G_DIR_SEPARATOR_S, "spellcheck.conf", NULL);
 
 	g_key_file_load_from_file(config, sc_info->config_file, G_KEY_FILE_NONE, NULL);
@@ -156,14 +172,14 @@ void plugin_init(GeanyData *data)
 		"spellcheck", "check_while_typing", FALSE);
 	sc_info->show_toolbar_item = utils_get_setting_boolean(config,
 		"spellcheck", "show_toolbar_item", TRUE);
+	sc_info->show_editor_menu_item = utils_get_setting_boolean(config,
+		"spellcheck", "show_editor_menu_item", TRUE);
 	sc_info->dictionary_dir = utils_get_setting_string(config,
 		"spellcheck", "dictionary_dir", NULL);
 	sc_info->use_msgwin = utils_get_setting_boolean(config, "spellcheck", "use_msgwin", FALSE);
 	g_key_file_free(config);
 	g_free(default_lang);
 
-	main_locale_init(LOCALEDIR, GETTEXT_PACKAGE);
-
 	sc_info->menu_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_SPELL_CHECK, NULL);
 	ui_add_document_sensitive(sc_info->menu_item);
 
@@ -194,7 +210,7 @@ static void dictionary_dir_button_clicked_cb(GtkButton *button, gpointer item)
 	GtkWidget *dialog;
 	gchar *text;
 
-	/* initialize the dialog */
+	/* initialise the dialog */
 	dialog = gtk_file_chooser_dialog_new(_("Select Directory"), NULL,
 					GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -225,7 +241,7 @@ static void dictionary_dir_button_clicked_cb(GtkButton *button, gpointer item)
 
 GtkWidget *plugin_configure(GtkDialog *dialog)
 {
-	GtkWidget *label, *vbox, *combo, *check_type, *check_msgwin, *check_toolbar;
+	GtkWidget *label, *vbox, *combo, *check_type, *check_msgwin, *check_toolbar, *check_editor_menu;
 #ifdef HAVE_ENCHANT_1_5
 	GtkWidget *entry_dir, *hbox, *button, *image;
 #endif
@@ -236,10 +252,17 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_type), sc_info->check_while_typing);
 	gtk_box_pack_start(GTK_BOX(vbox), check_type, FALSE, FALSE, 6);
 
-	check_toolbar = gtk_check_button_new_with_label(_("Show toolbar item to toggle spell checking"));
+	check_toolbar = gtk_check_button_new_with_label(
+		_("Show toolbar item to toggle spell checking"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_toolbar), sc_info->show_toolbar_item);
 	gtk_box_pack_start(GTK_BOX(vbox), check_toolbar, FALSE, FALSE, 3);
 
+	check_editor_menu = gtk_check_button_new_with_label(
+		_("Show editor menu item to show spelling suggestions"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_editor_menu),
+		sc_info->show_editor_menu_item);
+	gtk_box_pack_start(GTK_BOX(vbox), check_editor_menu, FALSE, FALSE, 3);
+
 	check_msgwin = gtk_check_button_new_with_label(
 		_("Print misspelled words and suggestions in the messages window"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_msgwin), sc_info->use_msgwin);
@@ -264,7 +287,7 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
 	entry_dir = gtk_entry_new();
-	ui_entry_add_clear_icon(GTK_WIDGET(entry_dir));
+	ui_entry_add_clear_icon(GTK_ENTRY(entry_dir));
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry_dir);
 	ui_widget_set_tooltip_text(entry_dir,
 		_("Read additional dictionary files from this directory. "
@@ -291,6 +314,7 @@ GtkWidget *plugin_configure(GtkDialog *dialog)
 	g_object_set_data(G_OBJECT(dialog), "check_type", check_type);
 	g_object_set_data(G_OBJECT(dialog), "check_msgwin", check_msgwin);
 	g_object_set_data(G_OBJECT(dialog), "check_toolbar", check_toolbar);
+	g_object_set_data(G_OBJECT(dialog), "check_editor_menu", check_editor_menu);
 	g_signal_connect(dialog, "response", G_CALLBACK(configure_response_cb), NULL);
 
 	gtk_widget_show_all(vbox);
