@@ -1,8 +1,8 @@
 /*
  *      speller.c - this file is part of Spellcheck, a Geany plugin
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2008-2009 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2008-2010 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -196,17 +196,26 @@ void sc_speller_check_document(GeanyDocument *doc)
 	}
 	g_free(dict_string);
 
-	for (i = first_line; i < last_line; i++)
+	if (first_line == last_line)
 	{
-		line = sci_get_line(doc->editor->sci, i);
-
-		suggestions_found += sc_speller_process_line(doc, i, line);
-
-		/* process other GTK events to keep the GUI being responsive */
-		while (g_main_context_iteration(NULL, FALSE));
-
+		line = sci_get_selection_contents(doc->editor->sci);
+		suggestions_found += sc_speller_process_line(doc, first_line, line);
 		g_free(line);
 	}
+	else
+	{
+		for (i = first_line; i < last_line; i++)
+		{
+			line = sci_get_line(doc->editor->sci, i);
+
+			suggestions_found += sc_speller_process_line(doc, i, line);
+
+			/* process other GTK events to keep the GUI being responsive */
+			while (g_main_context_iteration(NULL, FALSE));
+
+			g_free(line);
+		}
+	}
 	if (suggestions_found == 0 && sc_info->use_msgwin)
 		msgwin_msg_add(COLOR_BLUE, -1, NULL, _("The checked text is spelled correctly."));
 
@@ -378,7 +387,7 @@ void sc_speller_store_replacement(const gchar *old_word, const gchar *new_word)
 
 void sc_speller_reinit_enchant_dict(void)
 {
-	gchar *lang = sc_info->default_language;
+	const gchar *lang = sc_info->default_language;
 
 	/* Release a previous dict object */
 	if (sc_speller_dict != NULL)
@@ -404,9 +413,9 @@ void sc_speller_reinit_enchant_dict(void)
 #endif
 	create_dicts_array();
 
-	/* Check if the stored default dictionary is (still) avaiable, fall back to the first
+	/* Check if the stored default dictionary is (still) available, fall back to the first
 	 * one in the list if not */
-	if (! check_default_lang())
+	if (! NZV(lang) || ! check_default_lang())
 	{
 		if (sc_info->dicts->len > 0)
 		{
@@ -419,7 +428,10 @@ void sc_speller_reinit_enchant_dict(void)
 	}
 
 	/* Request new dict object */
-	sc_speller_dict = enchant_broker_request_dict(sc_speller_broker, lang);
+	if (NZV(lang))
+		sc_speller_dict = enchant_broker_request_dict(sc_speller_broker, lang);
+	else
+		sc_speller_dict = NULL;
 	if (sc_speller_dict == NULL)
 	{
 		broker_init_failed();
